// src/terminal/ascii.ts
import { magentaBright } from "yoctocolors";
var ascii = () => console.log(
  magentaBright(`
  _________       __    __  .__            _____  .__        __
 /   _____/ _____/  |__/  |_|  |   ____   /     \\ |__| _____/  |_
 \\_____  \\_/ __ \\   __\\   __\\  | _/ __ \\ /  \\ /  \\|  |/    \\   __\\
 /        \\  ___/|  |  |  | |  |_\\  ___//    Y    \\  |   |  \\  |
/_________/\\_____>__|  |__| |____/\\_____>____|____/__|___|__/__|
`)
);

// src/terminal/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/terminal/cancel.ts
import { inverse, redBright } from "yoctocolors";
var CancelError = class extends Error {
};
var cancel = (msg) => {
  console.log("");
  console.log(inverse(redBright(maskTokens(msg))));
  console.log("");
  throw new CancelError(msg);
};

// src/terminal/execute-command.ts
import { spawn } from "node:child_process";
async function executeCommand(command, args, options) {
  const child = spawn(command, args, { env: { ...process.env, ...options?.env } });
  process.stdin.pipe(child.stdin);
  const output = [];
  return new Promise((resolve, reject) => {
    child.stdout.on("data", (data) => {
      const maskedData = maskTokens(data.toString());
      if (!options?.silent) {
        process.stdout.write(maskedData);
      }
      output.push(maskedData);
    });
    child.stderr.on("data", (data) => {
      const maskedData = maskTokens(data.toString());
      if (!options?.silent) {
        process.stderr.write(maskedData);
      }
      output.push(maskedData);
    });
    child.on("error", (err) => reject(err));
    child.on("close", (code) => {
      if (code === 0 || code === null || code === 143) {
        process.stdin.unpipe(child.stdin);
        resolve(output);
        return;
      }
      reject(new Error(`Command "${command}" exited with code ${code}`));
    });
  });
}

// src/terminal/intro.ts
import { magentaBright as magentaBright2 } from "yoctocolors";
var intro = (msg) => {
  console.log("");
  console.log(magentaBright2(maskTokens(msg)));
  console.log("");
};

// src/terminal/note.ts
import { yellowBright } from "yoctocolors";
var note = (message, level = "info") => {
  const maskedMessage = maskTokens(message);
  console.log("");
  if (level === "warn") {
    console.warn(yellowBright(maskedMessage));
    return;
  }
  console.log(maskedMessage);
};

// src/terminal/list.ts
function list(title, items) {
  const formatItems = (items2) => {
    return items2.map((item) => {
      if (Array.isArray(item)) {
        return item.map((subItem) => `    \u2022 ${subItem}`).join("\n");
      }
      return `  \u2022 ${item}`;
    }).join("\n");
  };
  return note(`${title}:

${formatItems(items)}`);
}

// src/terminal/outro.ts
import { greenBright, inverse as inverse2 } from "yoctocolors";
var outro = (msg) => {
  console.log("");
  console.log(inverse2(greenBright(maskTokens(msg))));
  console.log("");
};

// src/terminal/spinner.ts
import isInCi from "is-in-ci";
import yoctoSpinner from "yocto-spinner";
import { redBright as redBright2 } from "yoctocolors";
var SpinnerError = class extends Error {
  constructor(message, originalError) {
    super(message);
    this.originalError = originalError;
    this.name = "SpinnerError";
  }
};
var spinner = async (options) => {
  const handleError = (error) => {
    const errorMessage = maskTokens(error.message);
    note(redBright2(`${errorMessage}

${error.stack}`));
    throw new SpinnerError(errorMessage, error);
  };
  if (isInCi) {
    try {
      return await options.task();
    } catch (err) {
      return handleError(err);
    }
  }
  const spinner2 = yoctoSpinner({ stream: process.stdout }).start(options.startMessage);
  try {
    const result = await options.task(spinner2);
    spinner2.success(options.stopMessage);
    await new Promise((resolve) => process.nextTick(resolve));
    return result;
  } catch (err) {
    spinner2.error(redBright2(`${options.startMessage} --> Error!`));
    return handleError(err);
  }
};

// src/string.ts
function capitalizeFirstLetter(val) {
  return String(val).charAt(0).toUpperCase() + String(val).slice(1);
}
function camelCaseToWords(s) {
  const result = s.replace(/([a-z])([A-Z])/g, "$1 $2");
  const withSpaces = result.replace(/([A-Z])([a-z])/g, " $1$2");
  const capitalized = capitalizeFirstLetter(withSpaces);
  return capitalized.replace(/\s+/g, " ").trim();
}

// src/terminal/table.ts
import { Table } from "console-table-printer";
import { whiteBright } from "yoctocolors";
function table(title, data) {
  note(title);
  if (!data || data.length === 0) {
    note("No data to display");
    return;
  }
  const columnKeys = Object.keys(data[0]);
  const table2 = new Table({
    columns: columnKeys.map((key) => ({
      name: key,
      title: whiteBright(camelCaseToWords(key)),
      alignment: "left"
    }))
  });
  table2.addRows(data);
  table2.printTable();
}
export {
  CancelError,
  SpinnerError,
  ascii,
  cancel,
  executeCommand,
  intro,
  list,
  maskTokens,
  note,
  outro,
  spinner,
  table
};
//# sourceMappingURL=terminal.mjs.map